@@ -1,25 +1,24 @@
-use Map::Metro::Standard;
+use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2300'; # VERSION
+package Map::Metro::Cmd;
+
 # ABSTRACT: The command line interface
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2400';
 
-package Map::Metro::Cmd  {
+use MooseX::App qw/Config Color/;
+use MooseX::AttributeShortcuts;
 
-    use MooseX::App qw/Config Color/;
+use Map::Metro;
+use Map::Metro::Shim;
 
-    use MooseX::AttributeShortcuts;
-    use Types::Standard -types;
+app_description 'Command line interface to Map::Metro';
 
-    use Map::Metro;
-    use Map::Metro::Shim;
+app_usage qq{map_metro.pl <command> [ <city> ]  [ <arguments> ]};
 
-    app_description 'Command line interface to Map::Metro';
-
-    app_usage qq{map_metro.pl <command> [ <city> ]  [ <arguments> ]};
-
-}
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -35,7 +34,7 @@ Map::Metro::Cmd - The command line interface
 
 =head1 VERSION
 
-Version 0.2300, released 2016-01-14.
+Version 0.2400, released 2016-02-24.
 
 =head1 SYNOPSIS
 
