@@ -1,25 +1,30 @@
-use Map::Metro::Standard::Moops;
+use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2300'; # VERSION
-# PODNAME: Map::Metro::Cmd::Available
+package Map::Metro::Cmd::Available;
+
 # ABSTRACT: Display installed maps
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2400';
 
-class Map::Metro::Cmd::Available extends Map::Metro::Cmd {
+use Map::Metro::Elk;
+use MooseX::App::Command;
+extends 'Map::Metro::Cmd';
 
-    use MooseX::App::Command;
+command_short_description 'Display installed maps';
 
-    command_short_description 'Display installed maps';
+sub run {
+    my $self = shift;
 
-    method run {
-        my $map = Map::Metro->new;
+    my $map = Map::Metro->new;
 
-        say "The following maps are available:\n";
-        say join "\n" => map { s{^Map::Metro::Plugin::Map::}{ }; $_ } grep { !/^Map::Metro::Plugin::Map$/ } $map->available_maps;
-    }
+    say "The following maps are available:\n";
+    say join "\n" => map { s{^Map::Metro::Plugin::Map::}{ }; $_ } grep { !/::Lines$/ } grep { !/^Map::Metro::Plugin::Map$/ } $map->available_maps;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -34,7 +39,7 @@ Map::Metro::Cmd::Available - Display installed maps
 
 =head1 VERSION
 
-Version 0.2300, released 2016-01-14.
+Version 0.2400, released 2016-02-24.
 
 =head1 SOURCE
 
