@@ -1,40 +1,45 @@
-use Map::Metro::Standard::Moops;
+use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2300'; # VERSION
-# PODNAME: Map::Metro::Graph::Connection
+package Map::Metro::Graph::Connection;
+
 # ABSTRACT: Connects two stations on a line
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2400';
 
-class Map::Metro::Graph::Connection {
+use Map::Metro::Elk;
+use Types::Standard qw/Maybe Int/;
+use Map::Metro::Types qw/LineStation Connection/;
 
-    has origin_line_station => (
-        is => 'ro',
-        isa => LineStation,
-        required => 1,
-    );
-    has destination_line_station => (
-        is => 'ro',
-        isa => LineStation,
-        required => 1,
-    );
-    has previous_connection => (
-        is => 'rw',
-        isa => Maybe[ Connection ],
-        predicate => 1,
-    );
-    has next_connection => (
-        is => 'rw',
-        isa => Maybe[ Connection ],
-        predicate => 1,
-    );
-    has weight => (
-        is => 'ro',
-        isa => Int,
-        required => 1,
-        default => 1,
-    );
-}
+has origin_line_station => (
+    is => 'ro',
+    isa => LineStation,
+    required => 1,
+);
+has destination_line_station => (
+    is => 'ro',
+    isa => LineStation,
+    required => 1,
+);
+has previous_connection => (
+    is => 'rw',
+    isa => Maybe[ Connection ],
+    predicate => 1,
+);
+has next_connection => (
+    is => 'rw',
+    isa => Maybe[ Connection ],
+    predicate => 1,
+);
+has weight => (
+    is => 'ro',
+    isa => Int,
+    required => 1,
+    default => 1,
+);
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -50,7 +55,7 @@ Map::Metro::Graph::Connection - Connects two stations on a line
 
 =head1 VERSION
 
-Version 0.2300, released 2016-01-14.
+Version 0.2400, released 2016-02-24.
 
 =head1 DESCRIPTION
 
