@@ -1,46 +1,55 @@
-use Map::Metro::Standard::Moops;
+use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2300'; # VERSION
-# PODNAME: Map::Metro::Graph::Line
+package Map::Metro::Graph::Line;
+
 # ABSTRACT: Meta information about a line
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2400';
 
-class Map::Metro::Graph::Line {
+use Map::Metro::Elk;
+use Types::Standard qw/Str Int/;
+use Map::Metro::Exceptions;
 
-    has id => (
-        is => 'ro',
-        isa => Str,
-        required => 1,
-    );
-    has name => (
-        is => 'ro',
-        isa => Str,
-        required => 1,
-    );
-    has description => (
-        is => 'ro',
-        isa => Str,
-        required => 1,
-    );
-    has color => (
-        is => 'rw',
-        isa => Str,
-        default => '#333333',
-    );
-    has width => (
-        is => 'rw',
-        isa => Int,
-        default => 3,
-    );
+has id => (
+    is => 'ro',
+    isa => Str,
+    required => 1,
+);
+has name => (
+    is => 'ro',
+    isa => Str,
+    required => 1,
+);
+has description => (
+    is => 'ro',
+    isa => Str,
+    required => 1,
+);
+has color => (
+    is => 'rw',
+    isa => Str,
+    default => '#333333',
+);
+has width => (
+    is => 'rw',
+    isa => Int,
+    default => 3,
+);
 
-    around BUILDARGS($orig: $self, %args) {
-        if($args{'id'} =~ m{([^a-z0-9])}i)  {
-            Map::Metro::Exception::LineIdContainsIllegalCharacter::LineIdContainsIllegalCharacter->throw(line_id => $args{'id'}, illegal_character => $_, ident => 'parser: line_id');
-        }
-        $self->$orig(%args);
+around BUILDARGS => sub {
+    my $orig = shift;
+    my $self = shift;
+    my %args = @_;
+
+    if($args{'id'} =~ m{([^a-z0-9])}i)  {
+        die lineid_contains_illegal_character line_id => $args{'id'}, illegal_character => $_;
     }
-}
+    $self->$orig(%args);
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -56,7 +65,7 @@ Map::Metro::Graph::Line - Meta information about a line
 
 =head1 VERSION
 
-Version 0.2300, released 2016-01-14.
+Version 0.2400, released 2016-02-24.
 
 =head1 DESCRIPTION
 
