@@ -1,40 +1,44 @@
-use Map::Metro::Standard::Moops;
+use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2300'; # VERSION
-# PODNAME: Map::Metro::Graph::Segment
+package Map::Metro::Graph::Segment;
+
 # ABSTRACT: All lines between two neighboring stations
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2400';
 
-class Map::Metro::Graph::Segment {
+use Map::Metro::Elk;
+use Types::Standard qw/ArrayRef Str Bool/;
+use Map::Metro::Types qw/Station/;
 
-    has line_ids => (
-        is => 'ro',
-        isa => ArrayRef[Str],
-        traits => ['Array'],
-        required => 1,
-        default => sub { [] },
-        handles => {
-            all_line_ids => 'elements',
-        }
-    );
-    has origin_station => (
-        is => 'ro',
-        isa => Station,
-        required => 1,
-    );
-    has destination_station => (
-        is => 'ro',
-        isa => Station,
-        required => 1,
-    );
-    has is_one_way => (
-        is => 'ro',
-        isa => Bool,
-        default => 0,
-    );
+has line_ids => (
+    is => 'ro',
+    isa => ArrayRef[Str],
+    traits => ['Array'],
+    required => 1,
+    default => sub { [] },
+    handles => {
+        all_line_ids => 'elements',
+    }
+);
+has origin_station => (
+    is => 'ro',
+    isa => Station,
+    required => 1,
+);
+has destination_station => (
+    is => 'ro',
+    isa => Station,
+    required => 1,
+);
+has is_one_way => (
+    is => 'ro',
+    isa => Bool,
+    default => 0,
+);
 
-}
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -50,7 +54,7 @@ Map::Metro::Graph::Segment - All lines between two neighboring stations
 
 =head1 VERSION
 
-Version 0.2300, released 2016-01-14.
+Version 0.2400, released 2016-02-24.
 
 =head1 DESCRIPTION
 
