@@ -1,30 +1,34 @@
-use Map::Metro::Standard::Moops;
+use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2300'; # VERSION
-# PODNAME: Map::Metro::Graph::Transfer
+package Map::Metro::Graph::Transfer;
+
 # ABSTRACT: Moving between two stations without a connection between them
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2400';
 
-class Map::Metro::Graph::Transfer {
+use Map::Metro::Elk;
+use Types::Standard qw/Int/;
+use Map::Metro::Types qw/Station/;
 
-    has origin_station => (
-        is => 'ro',
-        isa => Station,
-        required => 1,
-    );
-    has destination_station => (
-        is => 'ro',
-        isa => Station,
-        required => 1,
-    );
-    has weight => (
-        is => 'ro',
-        isa => Int,
-        default => 5,
-    );
+has origin_station => (
+    is => 'ro',
+    isa => Station,
+    required => 1,
+);
+has destination_station => (
+    is => 'ro',
+    isa => Station,
+    required => 1,
+);
+has weight => (
+    is => 'ro',
+    isa => Int,
+    default => 5,
+);
 
-}
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -40,7 +44,7 @@ Map::Metro::Graph::Transfer - Moving between two stations without a connection b
 
 =head1 VERSION
 
-Version 0.2300, released 2016-01-14.
+Version 0.2400, released 2016-02-24.
 
 =head1 DESCRIPTION
 
