@@ -1,19 +1,20 @@
-use 5.14.0;
+use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2300'; # VERSION
-# PODCLASSNAME
-# ABSTRACT: How to make your own map
-
 package Map::Metro::Plugin::Map;
 
+# ABSTRACT: How to make your own map
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2400';
+
 use Moose::Role;
+use namespace::autoclean;
 use MooseX::AttributeShortcuts;
 use File::ShareDir 'dist_dir';
 use Path::Tiny;
-use Types::Standard -types;
-use Types::Path::Tiny -types;
+use Types::Standard qw/Bool ArrayRef Str/;
+use Types::Path::Tiny qw/Path/;
 
 has mapfile => (
     is => 'ro',
@@ -55,7 +56,6 @@ sub version {
     return $self->map_version;
 }
 
-
 1;
 
 __END__
@@ -70,7 +70,7 @@ Map::Metro::Plugin::Map - How to make your own map
 
 =head1 VERSION
 
-Version 0.2300, released 2016-01-14.
+Version 0.2400, released 2016-02-24.
 
 =head1 SYNOPSIS
 
